==> qtjambi-quick-5.15.4-sources.jar: io/qt/quick/QQuickImageResponse.java <==
package io.qt.quick;


/**
 * <p>Interface for asynchronous image loading in QQuickAsyncImageProvider</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qquickimageresponse.html">QQuickImageResponse</a></p>
 */
public abstract class QQuickImageResponse extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QQuickImageResponse.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QQuickImageResponse {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.quick.QQuickTextureFactory textureFactory(){
            return textureFactory_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.quick.QQuickTextureFactory textureFactory_native_constfct(long __this__nativeId);
        
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qquickimageresponse.html#finished">QQuickImageResponse::finished()</a></p>
     */
    public final Signal0 finished = new Signal0();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qquickimageresponse.html#QQuickImageResponse">QQuickImageResponse::QQuickImageResponse()</a></p>
     */
    public QQuickImageResponse(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QQuickImageResponse instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qquickimageresponse.html#cancel">QQuickImageResponse::cancel()</a></p>
     */
    public void cancel(){
        cancel_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void cancel_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qquickimageresponse.html#errorString">QQuickImageResponse::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString(){
        return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String errorString_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qquickimageresponse.html#textureFactory">QQuickImageResponse::textureFactory()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.quick.QQuickTextureFactory textureFactory();
    
    @io.qt.QtUninvokable
    private native io.qt.quick.QQuickTextureFactory textureFactory_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QQuickImageResponse(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QQuickImageResponse(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QQuickImageResponse instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-quick-6.2.10-sources.jar: io/qt/quick/QQuickImageResponse.java <==
package io.qt.quick;


/**
 * <p>Interface for asynchronous image loading in QQuickAsyncImageProvider</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qquickimageresponse.html">QQuickImageResponse</a></p>
 */
public abstract class QQuickImageResponse extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QQuickImageResponse.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QQuickImageResponse {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.quick.QQuickTextureFactory textureFactory(){
            return textureFactory_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.quick.QQuickTextureFactory textureFactory_native_constfct(long __this__nativeId);
        
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qquickimageresponse.html#finished">QQuickImageResponse::finished()</a></p>
     */
    public final Signal0 finished = new Signal0();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qquickimageresponse.html#QQuickImageResponse">QQuickImageResponse::QQuickImageResponse()</a></p>
     */
    public QQuickImageResponse(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QQuickImageResponse instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qquickimageresponse.html#cancel">QQuickImageResponse::cancel()</a></p>
     */
    public void cancel(){
        cancel_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void cancel_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qquickimageresponse.html#errorString">QQuickImageResponse::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString(){
        return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String errorString_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qquickimageresponse.html#textureFactory">QQuickImageResponse::textureFactory()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.quick.QQuickTextureFactory textureFactory();
    
    @io.qt.QtUninvokable
    private native io.qt.quick.QQuickTextureFactory textureFactory_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QQuickImageResponse(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QQuickImageResponse(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QQuickImageResponse instance, QDeclarativeConstructor constructor);
    
}
